@@ -18,7 +18,7 @@ __author__ = "Hugo Angulo"
 __copyright__ = "Copyright 2020, CaosLab"
 __credits__ = ["Hugo Angulo"]
 __license__ = "MIT"
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __maintainer__ = "Hugo Angulo"
 __email__ = "hugoanda@andrew.cmu.edu"
 __status__ = "Production"
@@ -134,7 +134,7 @@ def main(argv=None):
         dcm_cleaned = list()
         if dcm_files.__len__() > 0:
             dcm_folders = dict()
-            dcm_recipe = os.path.join(current_path, "../util/deid.dicom")
+            dcm_recipe = os.path.join(current_path, "util/deid.dicom")
             for dcm_file in dcm_files:
                 _path, _file = os.path.split(dcm_file)
                 if directory_map[_path] not in dcm_folders:
@@ -154,8 +154,6 @@ def main(argv=None):
 
         for k, v in dcm_folders.items():
             try:
-                # dicom2nifti.convert_directory(dicom_directory=k, output_folder=k, compression=False, reorient=True)
-                # dicom2nifti.dicom_series_to_nifti(dicom_directory=k, output_folder=k, reorient=True)
                 converter.inputs.source_dir = k
                 converter.inputs.output_dir = k
                 converter.run()
